@@ -10,7 +10,7 @@ from datetime import datetime, date, timedelta
 import yaml
 import psycopg2
 import click
-import h5py
+from pathlib import Path
 from fdsnextender import FdsnExtender
 from resifdatareporter import __version__
 logging.basicConfig(format='%(asctime)s %(levelname)s: %(message)s', level=logging.INFO)
@@ -60,10 +60,8 @@ def scan_ph5_volume(volpath):
     - sinon, en analysant les volumes ph5, mais je ne sais pas si on en a vraiment besoin.
     """
     data = []
-    stations = [""]
     volume = os.path.realpath(volpath)+'/'
     logger.debug("Volume %s", volume)
-    starttime = datetime.now()
     proc = subprocess.Popen(["ls", volume], stdout=subprocess.PIPE)
     for l in io.TextIOWrapper(proc.stdout, encoding='utf-8'):
         network = l.strip()
@@ -75,28 +73,13 @@ def scan_ph5_volume(volpath):
             # Bon, ça n'a pas marché, on fait quoi ?
             logger.error("Unable to get year from path %s. Ignoring this one", path)
             continue
-        try:
-            # Récupération de la liste des stations
-            h5data = h5py.File(f"{path}/master.ph5",'r')
-            logger.debug("Master PH5 stations: %s",
-                    h5data['Experiment_g']['Maps_g'])
-            stations = [sta[6:] for sta in list(h5data['Experiment_g']['Maps_g']) if sta.startswith('Das_g_')]
-            logger.debug("%s stations in %s", len(stations), network)
-        except Exception as err:
-            logger.error("No master.ph5 file in %s. Let's assume there is one station", path)
-
         total = 0
-        for dirpath, dirnames, filenames in os.walk(path):
-            for i in filenames:
-                logger.debug("Scanning %s: file %s", network, i)
-                if i.endswith('ph5'):
-                    total = total + os.path.getsize(f"{path}/{i}")
+        for path in Path(path).rglob('*.ph5'):
+            total = total + path.stat().st_size
         logger.debug("Total size of %s is %s (%s GB)", network, total, total/(1024**3) )
         # Make a statistic array with those stations dividing total size on each station.
-        per_station_size = int(total / len(stations))
-        for sta in stations:
-            data.append({'type': 'ph5_validated', 'year': year, 'network': network, 'station': sta,
-                         'channel': None, 'quality': None, 'size': per_station_size})
+        data.append({'type': 'ph5', 'year': year, 'network': network, 'station': None,
+                         'channel': None, 'quality': None, 'size': total})
     return data
 
 
